@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::5_0::Role::Bulk;
-$Search::Elasticsearch::Client::5_0::Role::Bulk::VERSION = '6.00';
+$Search::Elasticsearch::Client::5_0::Role::Bulk::VERSION = '6.80';
 use Moo::Role;
 requires 'add_action', 'flush';
 
@@ -274,15 +274,15 @@ Search::Elasticsearch::Client::5_0::Role::Bulk - Provides common functionality t
 
 =head1 VERSION
 
-version 6.00
+version 6.80
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
