@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::5_0::Scroll;
-$Search::Elasticsearch::Client::5_0::Scroll::VERSION = '6.00';
+$Search::Elasticsearch::Client::5_0::Scroll::VERSION = '6.80';
 use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use namespace::clean;
@@ -126,7 +126,7 @@ Search::Elasticsearch::Client::5_0::Scroll - A helper module for scrolled search
 
 =head1 VERSION
 
-version 6.00
+version 6.80
 
 =head1 SYNOPSIS
 
@@ -369,11 +369,11 @@ How long the original search plus all subsequent batches took, in milliseconds.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
