@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::5_0::TestServer;
-$Search::Elasticsearch::Client::5_0::TestServer::VERSION = '6.00';
+$Search::Elasticsearch::Client::5_0::TestServer::VERSION = '6.80';
 use strict;
 use warnings;
 
@@ -41,15 +41,15 @@ Search::Elasticsearch::Client::5_0::TestServer - Client-specific backend for Sea
 
 =head1 VERSION
 
-version 6.00
+version 6.80
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
